@@ -41,26 +41,32 @@ typedef struct {
 	au_event_t e;		// event - time & serial number
 } event_list_t;
 
-void aup_list_create(event_list_t *l) hidden;
-void aup_list_clear(event_list_t* l) hidden;
-static inline unsigned int aup_list_get_cnt(event_list_t *l) { return l->cnt; }
+static inline unsigned int aup_list_get_cnt(event_list_t *l) { return l ? l->cnt : 0; }
 static inline void aup_list_first(event_list_t *l) { l->cur = l->head; }
 static inline rnode *aup_list_get_cur(event_list_t *l) { return l->cur; }
-rnode *aup_list_next(event_list_t *l) hidden;
-int aup_list_append(event_list_t *l, char *record, int list_idx, unsigned int line_number) hidden;
-//int aup_list_get_event(event_list_t* l, au_event_t *e) hidden;
-int aup_list_set_event(event_list_t* l, au_event_t *e) hidden;
+
+AUDIT_HIDDEN_START
+
+void aup_list_create(event_list_t *l);
+void aup_list_clear(event_list_t* l);
+rnode *aup_list_next(event_list_t *l);
+int aup_list_append(event_list_t *l, char *record, int list_idx,
+	unsigned int line_number);
+//int aup_list_get_event(event_list_t* l, au_event_t *e);
+int aup_list_set_event(event_list_t* l, au_event_t *e);
 
 /* Given a message type, find the matching node */
-rnode *aup_list_find_rec(event_list_t *l, int i) hidden;
+rnode *aup_list_find_rec(event_list_t *l, int i);
 
 /* Seek to a specific record number */
-rnode *aup_list_goto_rec(event_list_t *l, int i) hidden;
+rnode *aup_list_goto_rec(event_list_t *l, int i);
 
 /* Given two message types, find the first matching node */
-rnode *aup_list_find_rec_range(event_list_t *l, int low, int high) hidden;
+rnode *aup_list_find_rec_range(event_list_t *l, int low, int high);
 
-int aup_list_first_field(event_list_t *l) hidden;
+int aup_list_first_field(event_list_t *l);
+
+AUDIT_HIDDEN_END
 
 #endif
 
