@@ -56,7 +56,7 @@ _S(AUPARSE_TYPE_ESCAPED,	"cwd"		)
 _S(AUPARSE_TYPE_ESCAPED,	"cmd"		)
 _S(AUPARSE_TYPE_ESCAPED,	"acct"		)
 _S(AUPARSE_TYPE_ESCAPED,	"dir"		)
-_S(AUPARSE_TYPE_ESCAPED,	"key"		)
+_S(AUPARSE_TYPE_ESCAPED_KEY,	"key"		)
 _S(AUPARSE_TYPE_ESCAPED,	"vm"		)
 _S(AUPARSE_TYPE_ESCAPED,	"old-chardev"	)
 _S(AUPARSE_TYPE_ESCAPED,	"new-chardev"	)
@@ -133,4 +133,5 @@ _S(AUPARSE_TYPE_HOOK,		"hook"		)
 _S(AUPARSE_TYPE_NETACTION,	"action"	)
 _S(AUPARSE_TYPE_MACPROTO,	"macproto"	)
 _S(AUPARSE_TYPE_ESCAPED,	"invalid_context")
+_S(AUPARSE_TYPE_IOCTL_REQ,	"ioctlcmd"	)
 
