@@ -1,5 +1,5 @@
 /* aarch64_table.h --
- * Copyright 2013-15 Red Hat Inc., Durham, North Carolina.
+ * Copyright 2013-16 Red Hat Inc., Durham, North Carolina.
  * All Rights Reserved.
  *
  * This library is free software; you can redistribute it and/or
@@ -286,3 +286,7 @@ _S(278, "getrandom")
 _S(279, "memfd_create")
 _S(280, "bpf")
 _S(281, "execveat")
+_S(282, "userfaultfd")
+_S(283, "membarrier")
+_S(284, "mlock2")
+_S(285, "copy_file_range")
