@@ -1,5 +1,5 @@
 /* arm_table.h --
- * Copyright 2009-10,2013-15 Red Hat Inc., Durham, North Carolina.
+ * Copyright 2009-10,2013-16 Red Hat Inc., Durham, North Carolina.
  * All Rights Reserved.
  *
  * This library is free software; you can redistribute it and/or
@@ -371,3 +371,7 @@ _S(384, "getrandom")
 _S(385, "memfd_create")
 _S(386, "bpf")
 _S(387, "execveat")
+_S(388, "userfaultfd")
+_S(389, "membarrier")
+_S(390, "mlock2")
+_S(391, "copy_file_range")
