@@ -1,5 +1,5 @@
 /* ia64_table.h --
- * Copyright 2005-15 Red Hat Inc., Durham, North Carolina.
+ * Copyright 2005-16 Red Hat Inc., Durham, North Carolina.
  * All Rights Reserved.
  *
  * This library is free software; you can redistribute it and/or
@@ -333,3 +333,8 @@ _S(1339, "getrandom")
 _S(1340, "memfd_create")
 _S(1341, "bpf")
 _S(1342, "execveat")
+_S(1343, "userfaultfd")
+_S(1344, "membarrier")
+_S(1345, "kcmp")
+_S(1346, "mlock2")
+_S(1347, "copy_file_range")
