@@ -39,7 +39,9 @@
 #include <limits.h>	/* for PATH_MAX */
 #include <sys/stat.h>
 #include <sys/types.h>
-
+#ifdef HAVE_LIBCAP_NG
+#include <cap-ng.h>
+#endif
 #include "libaudit.h"
 #include "private.h"
 #include "errormsg.h"
@@ -396,7 +398,7 @@ int audit_is_enabled(int fd)
 		   and disable the audit system get in. ECONNREFUSED is
 		   issued by the kernel when there is "no on listening". */
 		return 0;
-	} else if (rc == -EPERM && geteuid() != 0) {
+	} else if (rc == -EPERM && !audit_can_control()) {
 		/* If we get this, then the kernel supports auditing
 		 * but we don't have enough privilege to write to the
 		 * socket. Therefore, we have already been authenticated
@@ -513,7 +515,8 @@ int audit_set_backlog_wait_time(int fd, uint32_t bwt)
 
 int audit_set_feature(int fd, unsigned feature, unsigned value, unsigned lock)
 {
-#if HAVE_DECL_AUDIT_FEATURE_VERSION
+#if defined(HAVE_DECL_AUDIT_FEATURE_VERSION) && \
+    defined(HAVE_STRUCT_AUDIT_STATUS_FEATURE_BITMAP)
 	int rc;
 	struct audit_features f;
 
@@ -537,7 +540,8 @@ int audit_set_feature(int fd, unsigned feature, unsigned value, unsigned lock)
 
 int audit_request_features(int fd)
 {
-#if HAVE_DECL_AUDIT_FEATURE_VERSION
+#if defined(HAVE_DECL_AUDIT_FEATURE_VERSION) && \
+    defined(HAVE_STRUCT_AUDIT_STATUS_FEATURE_BITMAP)
 	int rc;
 	struct audit_features f;
 
@@ -556,7 +560,8 @@ int audit_request_features(int fd)
 
 extern int  audit_set_loginuid_immutable(int fd)
 {
-#if HAVE_DECL_AUDIT_FEATURE_VERSION
+#if defined(HAVE_DECL_AUDIT_FEATURE_VERSION) && \
+    defined(HAVE_STRUCT_AUDIT_STATUS_FEATURE_BITMAP)
 	return audit_set_feature(fd, AUDIT_FEATURE_LOGINUID_IMMUTABLE, 1, 1);
 #else
 	errno = EINVAL;
@@ -577,7 +582,8 @@ static void load_feature_bitmap(void)
 		return;
 	}
 
-#if HAVE_DECL_AUDIT_FEATURE_VERSION
+#if defined(HAVE_DECL_AUDIT_FEATURE_VERSION) && \
+    defined(HAVE_STRUCT_AUDIT_STATUS_FEATURE_BITMAP)
 	if ((rc = audit_request_status(fd)) > 0) {
 		struct audit_reply rep;
 		int i;
@@ -1657,6 +1663,8 @@ void audit_rule_free_data(struct audit_rule_data *rule)
 	free(rule);
 }
 
+// This use is OK because its creating rules for the local
+// machine and is looking up a local user.
 static int audit_name_to_uid(const char *name, uid_t *uid)
 {
 	struct passwd *pw;
@@ -1720,3 +1728,43 @@ void audit_number_to_errmsg(int errnumber, const char *opt)
 	}
 }
 #endif
+
+int audit_can_control(void)
+{
+#ifdef HAVE_LIBCAP_NG
+	void *state = capng_save_state();
+	int rc = capng_have_capability(CAPNG_EFFECTIVE, CAP_AUDIT_CONTROL);
+	capng_restore_state(&state);
+
+	return rc;
+#else
+	return (geteuid() == 0);
+#endif
+}
+
+int audit_can_write(void)
+{
+#ifdef HAVE_LIBCAP_NG
+	void *state = capng_save_state();
+	int rc = capng_have_capability(CAPNG_EFFECTIVE, CAP_AUDIT_WRITE);
+	capng_restore_state(&state);
+
+	return rc;
+#else
+	return (geteuid() == 0);
+#endif
+}
+
+int audit_can_read(void)
+{
+#if defined ( HAVE_LIBCAP_NG ) && ( CAP_AUDIT_READ )
+	void *state = capng_save_state();
+	int rc = capng_have_capability(CAPNG_EFFECTIVE, CAP_AUDIT_READ);
+	capng_restore_state(&state);
+
+	return rc;
+#else
+	return (geteuid() == 0);
+#endif
+}
+
