@@ -129,7 +129,8 @@ static void usage(void)
      "    -v                  Version\n"
      "    -w <path>           Insert watch at <path>\n"
      "    -W <path>           Remove watch at <path>\n"
-#if HAVE_DECL_AUDIT_FEATURE_VERSION
+#if defined(HAVE_DECL_AUDIT_FEATURE_VERSION) && \
+    defined(HAVE_STRUCT_AUDIT_STATUS_FEATURE_BITMAP)
      "    --loginuid-immutable   Make loginuids unchangeable once set\n"
 #endif
 #if HAVE_DECL_AUDIT_VERSION_BACKLOG_WAIT_TIME
@@ -516,7 +517,8 @@ int parse_syscall(struct audit_rule_data *rule_new, const char *optarg)
 
 struct option long_opts[] =
 {
-#if HAVE_DECL_AUDIT_FEATURE_VERSION
+#if defined(HAVE_DECL_AUDIT_FEATURE_VERSION) && \
+    defined(HAVE_STRUCT_AUDIT_STATUS_FEATURE_BITMAP)
   {"loginuid-immutable", 0, NULL, 1},
 #endif
 #if HAVE_DECL_AUDIT_VERSION_BACKLOG_WAIT_TIME
@@ -823,6 +825,11 @@ static int setopt(int count, int lineno, char *vars[])
 			break;
 		}
 
+		// Keys need to get handled differently
+		if (strncmp(optarg, "key=", 4) == 0) {
+			optarg += 4;
+			goto process_keys;
+		}
 		rc = audit_rule_fieldpair_data(&rule_new,optarg,flags);
 		if (rc != 0) {
 			audit_number_to_errmsg(rc, optarg);
@@ -938,10 +945,14 @@ static int setopt(int count, int lineno, char *vars[])
 			audit_msg(LOG_ERR,
 		    "key option needs a watch or syscall given prior to it");
 			retval = -1;
+			break;
 		} else if (!optarg) {
 			audit_msg(LOG_ERR, "key option needs a value");
 			retval = -1;
-		} else if ((strlen(optarg)+strlen(key)+(!!key[0])) >
+			break;
+		}
+process_keys:
+		if ((strlen(optarg)+strlen(key)+(!!key[0])) >
 							AUDIT_MAX_KEY_LEN) {
 			audit_msg(LOG_ERR, "key option exceeds size limit");
 			retval = -1;
@@ -1310,7 +1321,7 @@ int main(int argc, char *argv[])
 #ifndef DEBUG
 	/* Make sure we are root if we do anything except help */
 	if (!(argc == 2 && (strcmp(argv[1], "--help")==0 ||
-			strcmp(argv[1], "-h") == 0)) && (geteuid() != 0)) {
+			strcmp(argv[1], "-h") == 0)) && !audit_can_control()) {
 		audit_msg(LOG_WARNING, "You must be root to run this program.");
 		return 4;
 	}
