@@ -173,6 +173,7 @@ static const struct nv_list log_formats[] =
 {
   {"raw",  LF_RAW },
   {"nolog", LF_NOLOG },
+  {"enriched", LF_ENRICHED },
   { NULL,  0 }
 };
 
@@ -616,13 +617,11 @@ static int log_file_parser(struct nv_pair *nv, int line,
 		return 1;
 	}
 	if ( (buf.st_mode & (S_IXUSR|S_IWGRP|S_IXGRP|S_IRWXO)) ) {
-		audit_msg(LOG_ERR, "%s permissions should be 0600 or 0640",
+		audit_msg(LOG_WARNING, "%s permissions should be 0600 or 0640",
 				nv->value);
-		return 1;
 	}
 	if ( !(buf.st_mode & S_IWUSR) ) {
-		audit_msg(LOG_ERR, "audit log is not writable by owner");
-		return 1;
+		audit_msg(LOG_WARNING, "audit log is not writable by owner");
 	}
 
 	free((void *)config->log_file);
@@ -659,8 +658,8 @@ static int num_logs_parser(struct nv_pair *nv, int line,
 			strerror(errno), line);
 		return 1;
 	}
-	if (i > 99) {
-		audit_msg(LOG_ERR, "num_logs must be 99 or less");
+	if (i > 999) {
+		audit_msg(LOG_ERR, "num_logs must be 999 or less");
 		return 1;
 	}
 	config->num_logs = i;
