@@ -1,5 +1,5 @@
 /* auditd-dispatch.c -- 
- * Copyright 2005-07,2013 Red Hat Inc., Durham, North Carolina.
+ * Copyright 2005-07,2013,2016 Red Hat Inc., Durham, North Carolina.
  * All Rights Reserved.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -38,6 +38,7 @@
 static int disp_pipe[2] = {-1, -1};
 static pid_t pid = 0;
 static int n_errs = 0;
+static int protocol_ver = AUDISP_PROTOCOL_VER;
 #define REPORT_LIMIT 10
 
 int dispatcher_pid(void)
@@ -81,6 +82,12 @@ int init_dispatcher(const struct daemon_conf *config)
 		return 1;
 	}
 
+	/* If the events have enriched data, we are protocol 2 */
+	if (config->log_format == LF_ENRICHED)
+		protocol_ver = AUDISP_PROTOCOL_VER2;
+	else
+		protocol_ver = AUDISP_PROTOCOL_VER;
+
 	/* Make both disp_pipe non-blocking */
 	if (config->qos == QOS_NON_BLOCKING) {
 		if (set_flags(disp_pipe[0], O_NONBLOCK) < 0 ||
@@ -151,6 +158,11 @@ void reconfigure_dispatcher(const struct daemon_conf *config)
 		kill(pid, SIGHUP);
 	else
 		init_dispatcher(config);
+
+	if (config->log_format == LF_ENRICHED)
+		protocol_ver = AUDISP_PROTOCOL_VER2;
+	else
+		protocol_ver = AUDISP_PROTOCOL_VER;
 }
 
 /* Returns -1 on err, 0 on success, and 1 if eagain occurred and not an err */
@@ -168,15 +180,21 @@ int dispatch_event(const struct audit_reply *rep, int is_err)
 					rep->type == AUDIT_DAEMON_ROTATE)
 		return 0;
 
-	hdr.ver = AUDISP_PROTOCOL_VER; /* Hard-coded to current protocol */
+	hdr.ver = protocol_ver;
 	hdr.hlen = sizeof(struct audit_dispatcher_header);
 	hdr.type = rep->type;
-	hdr.size = rep->len;
 
 	vec[0].iov_base = (void*)&hdr;
 	vec[0].iov_len = sizeof(hdr);
-	vec[1].iov_base = (void*)rep->message;
-	vec[1].iov_len = rep->len;
+	if (protocol_ver == AUDISP_PROTOCOL_VER) {
+		hdr.size = rep->msg.nlh.nlmsg_len;
+		vec[1].iov_base = (void*)rep->msg.data;
+	} else if (protocol_ver == AUDISP_PROTOCOL_VER2) {
+		hdr.size = rep->len;
+		vec[1].iov_base = (void*)rep->message;
+	} else
+		return 0;
+	vec[1].iov_len = hdr.size;
 
 	do {
 		rc = writev(disp_pipe[1], vec, 2);
