@@ -1,6 +1,6 @@
 /*
 * ausearch-report.c - Format and output events
-* Copyright (c) 2005-09,2011-13 Red Hat Inc., Durham, North Carolina.
+* Copyright (c) 2005-09,2011-13,2016 Red Hat Inc., Durham, North Carolina.
 * All Rights Reserved. 
 *
 * This software may be freely redistributed and/or modified under the
@@ -47,6 +47,25 @@ static int cur_syscall = -1;
 /* The first syscall argument */
 static unsigned long long a0, a1;
 
+/* tracks state of interpretations */
+static int loaded = 0;
+
+void ausearch_load_interpretations(const lnode *n)
+{
+	if (loaded == 0) {
+		_auparse_load_interpretations(n->interp);
+		loaded = 1;
+	}
+}
+
+void ausearch_free_interpretations(void)
+{
+	if (loaded) {
+		_auparse_free_interpretations();
+		loaded = 0;
+	}
+}
+
 /* This function branches to the correct output format */
 void output_record(llist *l)
 {
@@ -80,6 +99,7 @@ static void output_raw(llist *l)
 		return;
 	}
 	do {
+		n->message[n->mlen] = AUDIT_INTERP_SEPARATOR;
 		puts(n->message);
 	} while ((n=list_next(l)));
 }
@@ -200,6 +220,7 @@ no_print:
 	}
 
 	// for each item.
+	ausearch_load_interpretations(n);
 	found = 0;
 	while (str && *str && (ptr = strchr(str, '='))) {
 		char *name, *val;
@@ -274,6 +295,8 @@ no_print:
 		// print interpreted string
 		interpret(name, val, comma, n->type);
 	}
+	ausearch_free_interpretations();
+
 	// If nothing found, just print out as is
 	if (!found && ptr == NULL && str)
 		safe_print_string(str, 1);
